diff layer/TimeInstantLayer.cpp @ 587:4806715f7a19

Seems to be a bad idea to use plain DEBUG symbol on OS/X (system wants it)
author Chris Cannam
date Tue, 14 Jun 2011 15:27:05 +0100
parents f4960f8ce798
children 3c29f7c1f079
line wrap: on
line diff
--- a/layer/TimeInstantLayer.cpp	Tue Jun 14 14:48:29 2011 +0100
+++ b/layer/TimeInstantLayer.cpp	Tue Jun 14 15:27:05 2011 +0100
@@ -60,7 +60,7 @@
     connectSignals(m_model);
 
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::setModel(" << model << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::setModel(" << model << ")" << endl;
 #endif
 
     if (m_model && m_model->getRDFTypeURI().endsWith("Segment")) {
@@ -363,7 +363,7 @@
 	oddBrushColour.setAlpha(100);
     }
 
 //    DEBUG << "TimeInstantLayer::paint: resolution is "
 //	      << m_model->getResolution() << " frames" << endl;
 
     QPoint localPos;
@@ -469,7 +469,7 @@
 TimeInstantLayer::drawStart(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::drawStart(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::drawStart(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model) return;
@@ -492,7 +492,7 @@
 TimeInstantLayer::drawDrag(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::drawDrag(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::drawDrag(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model || !m_editing) return;
@@ -509,7 +509,7 @@
 TimeInstantLayer::drawEnd(View *, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::drawEnd(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::drawEnd(" << e->x() << ")" << endl;
 #endif
     if (!m_model || !m_editing) return;
     QString newName = tr("Add Point at %1 s")
@@ -570,7 +570,7 @@
 TimeInstantLayer::editStart(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::editStart(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::editStart(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model) return;
@@ -592,7 +592,7 @@
 TimeInstantLayer::editDrag(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::editDrag(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::editDrag(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model || !m_editing) return;
@@ -615,7 +615,7 @@
 TimeInstantLayer::editEnd(View *, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    DEBUG << "TimeInstantLayer::editEnd(" << e->x() << ")" << endl;
+    SVDEBUG << "TimeInstantLayer::editEnd(" << e->x() << ")" << endl;
 #endif
     if (!m_model || !m_editing) return;
     if (m_editingCommand) {
@@ -363,7 +363,7 @@
     }
 
-//    DEBUG << "TimeInstantLayer::paint: resolution is "
+//    SVDEBUG << "TimeInstantLayer::paint: resolution is "
 //	      << m_model->getResolution() << " frames" << endl;
 